@@ -17,28 +17,33 @@
 UNBUILDABLE_IMAGES = {
     'aarch64': {
         "bifrost-base",        # someone need to get upstream working first
-        "prometheus-msteams",  # no aarch64 binary
-        "prometheus-mtail",    # no aarch64 binary
     },
 
     # Issues for SHA1 keys:
     # https://github.com/grafana/grafana/issues/41036
     'centos': {
-        "bifrost-base",          # Using missing branch instead of EOL tag
         "hacluster-pcs",         # Missing crmsh package
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
         "ovsdpdk",               # Not supported on CentOS
         "tgtd",                  # Not supported on CentOS
     },
 
+    'centos+stream9': {
+        "valkey-base"            # Not supported on Stream 9
+    },
+
+    'centos+stream10': {
+        "collectd",              # No opstools repo for EL10
+        "redis-base",            # No redis repo for EL10
+        "telegraf",              # No opstools repo for EL10
+    },
+
     'debian': {
-        "bifrost-base",          # Using missing branch instead of EOL tag
         "openvswitch-netcontrold",
         # https://bugs.launchpad.net/kolla/+bug/2027668
     },
 
     'rocky': {
-        "bifrost-base",          # Using missing branch instead of EOL tag
         "collectd",              # Missing libpqos.so.4()(64bit)
         "hacluster-pcs",         # Missing crmsh package
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
@@ -46,15 +51,21 @@ UNBUILDABLE_IMAGES = {
         "tgtd",                  # Not supported on CentOS
     },
 
+    'rocky+9': {
+        "valkey-base"            # Not supported on Rocky 9
+    },
+
+    'rocky+10': {
+        "redis-base",             # No Redis in EL10
+        "telegraf"                # Missing opstools repo
+    },
+
     'ubuntu': {
-        "bifrost-base",          # Using missing branch instead of EOL tag
     },
 
     'ubuntu+aarch64': {
-        "barbican-base",  # https://github.com/unbit/uwsgi/issues/2434
     },
 
     'centos+aarch64': {
-        "telegraf",      # no binary package
     },
 }
